==> anabolicset-1.1.0.tgz: package/test/test.js <==
const assert = require('assert')
const AnabolicSet = require('/src/anabolicset.js')

function set(...rest) {
    return new AnabolicSet(...rest)
}

describe('constructor() test', () => {
    it('should remove duplicate numbers', () => {
        assert.deepEqual(set([1, 2, 2, 3]).getValues(), [1, 2, 3])
    })
    it('should remove duplicate ids', () => {
        assert.deepEqual(set([{ id: 1 }, { id: 2 }, { id: 2 }], (obj) => obj.id).getValues(), [{ id: 1 }, { id: 2 }])
    })
    it('should handle object parameter', () => {
        assert.deepEqual(set({ a: 'a', b: 'b', c: 'c' }).getValues(), ['a', 'b', 'c'])
    })
    it('should handle primitive data type parameter', () => {
        assert.deepEqual(set(1).getValues(), [1])
        assert.deepEqual(set('1').getValues(), ['1'])
    })
})

describe('add() test', () => {
    it('should handle array parameter', () => {
        const s = set([1, 2, 3])
        s.add([2, 3, 4])
        assert.deepEqual(s.getValues(), [1, 2, 3, 4])
    })
    it('should handle object parameter', () => {
        const s = set([1, 2, 3])
        s.add({ four: 4, five: 5, six: 6 })
        assert.deepEqual(s.getValues(), [1, 2, 3, 4, 5, 6])
    })
    it('should handle primitive data type parameter', () => {
        const s = set([1, 2, 3])
        s.add(4)
        assert.deepEqual(s.getValues(), [1, 2, 3, 4])
    })
})

describe('clear() test', () => {
    it('should be empty', () => {
        const s = set([1, 2, 3])
        s.clear()
        assert.deepEqual(s.getValues(), [])
    })
})

describe('delete() test', () => {
    it('should handle array parameter', () => {
        const s = set([1, 2, 3])
        s.delete([1, 2])
        assert.deepEqual(s.getValues(), [3])
    })
    it('should handle object parameter', () => {
        const s = set([1, 2, 3])
        s.delete({ one: 1, two: 2 })
        assert.deepEqual(s.getValues(), [3])
    })
    it('should handle primitive data type parameter', () => {
        const s = set([1, 2, 3])
        s.delete(1)
        assert.deepEqual(s.getValues(), [2, 3])
    })
})

describe('entries() test', () => {
    it('should give entries', () => {
        const s = set([1, 2, 3])
        assert.deepEqual(s.getValues(), [[1, 1], [2, 2], [3, 3]])
    })
})

==> anabolicset-1.2.0.tgz: package/test/test.js <==
const assert = require('assert')
const AnabolicSet = require('anabolicset/src/anabolicset')

function set(...rest) {
    return new AnabolicSet(...rest)
}

describe('constructor() test', () => {
    it('should remove duplicate numbers', () => {
        assert.deepEqual(set([1, 2, 2, 3]).getValues(), [1, 2, 3])
    })
    it('should remove duplicate ids', () => {
        assert.deepEqual(set([{ id: 1 }, { id: 2 }, { id: 2 }], (obj) => obj.id).getValues(), [{ id: 1 }, { id: 2 }])
    })
    it('should handle object parameter', () => {
        assert.deepEqual(set({ a: 'a', b: 'b', c: 'c' }).getValues(), ['a', 'b', 'c'])
    })
    it('should handle primitive data type parameter', () => {
        assert.deepEqual(set(1).getValues(), [1])
        assert.deepEqual(set('1').getValues(), ['1'])
    })
})

describe('add() test', () => {
    it('should handle array parameter', () => {
        const s = set([1, 2, 3])
        s.add([2, 3, 4])
        assert.deepEqual(s.getValues(), [1, 2, 3, 4])
    })
    it('should handle object parameter', () => {
        const s = set([1, 2, 3])
        s.add({ four: 4, five: 5, six: 6 })
        assert.deepEqual(s.getValues(), [1, 2, 3, 4, 5, 6])
    })
    it('should handle primitive data type parameter', () => {
        const s = set([1, 2, 3])
        s.add(4)
        assert.deepEqual(s.getValues(), [1, 2, 3, 4])
    })
})

describe('clear() test', () => {
    it('should be empty', () => {
        const s = set([1, 2, 3])
        s.clear()
        assert.deepEqual(s.getValues(), [])
    })
})

describe('delete() test', () => {
    it('should handle array parameter', () => {
        const s = set([1, 2, 3])
        s.delete([1, 2])
        assert.deepEqual(s.getValues(), [3])
    })
    it('should handle object parameter', () => {
        const s = set([1, 2, 3])
        s.delete({ one: 1, two: 2 })
        assert.deepEqual(s.getValues(), [3])
    })
    it('should handle primitive data type parameter', () => {
        const s = set([1, 2, 3])
        s.delete(1)
        assert.deepEqual(s.getValues(), [2, 3])
    })
})

describe('entries() test', () => {
    it('should give entries', () => {
        const s = set([1, 2, 3])
        assert.deepEqual(s.entries(), [[1, 1], [2, 2], [3, 3]])
    })
})

describe('has() test', () => {
    it('should have number', () => {
        const s = set([1, 2, 3])
        assert.equal(s.has(3), true)
    })
    it('should not have string', () => {
        const s = set([1, 2, 3])
        assert.equal(s.has('4'), false)
    })
})
